@@ -1,6 +1,7 @@
 """Main classes."""
 from cachetools import TTLCache
 from cachetools.keys import hashkey
+from distutils.util import strtobool
 from functools import cached_property, partial
 from json import dumps
 from pycognito import Cognito
@@ -228,10 +229,7 @@ class Bot(Device):
 
     def turn(self, value):
         """Set bot state."""
-        assert value.lower() in ("off", "on")
-        assert self.mode == "toggle"
-
-        self.state = True if value.lower() == "on" else False
+        self.state = strtobool(value)
 
     def press(self):
         """Press bot button."""
@@ -241,7 +239,7 @@ class Bot(Device):
 
     def toggle(self):
         """Toggle bot state."""
-        self.turn("off" if self.state else "on")
+        self.state = not self.state
 
 
 class CurtainGroup(Device):
@@ -329,6 +327,14 @@ class CurtainGroup(Device):
         """Close curtains."""
         self.children[0].close()
 
+    def move(self, value):
+        """Move curtains."""
+        self.children[0].move(value)
+
+    def toggle(self):
+        """Toggle curtains."""
+        self.children[0].toggle()
+
 
 class Curtain(Device):
     """Curtain device class."""
@@ -359,15 +365,19 @@ class Curtain(Device):
 
         if self._device["isMaster"]:
             self._position = self._status["status"]["position"]
+        else:
+            self._position = None
 
         if "battery" in self._status["status"]:
             self._battery = self._status["status"]["battery"]
+        else:
+            self._battery = None
 
     @property
     def position(self):
         """Current curtain position."""
         self._refresh()
-        return self.state
+        return self._position
 
     @position.setter
     def position(self, value):
@@ -387,9 +397,9 @@ class Curtain(Device):
         assert self.master
 
         if value:
-            self.open()
-        else:
             self.close()
+        else:
+            self.open()
 
     @property
     def moving(self):
@@ -409,6 +419,26 @@ class Curtain(Device):
 
         self.move(100)
 
+    def move(self, value):
+        """Move curtain."""
+        assert self.master
+
+        if value == "open":
+            return self.open()
+        elif value == "close":
+            return self.close()
+        elif value == "closed":
+            return self.close()
+
+        assert int(value) >= 0
+        assert int(value) <= 100
+
+        self.position = int(value)
+
+    def toggle(self):
+        """Toggle curtain."""
+        self.state = not self.state
+
 
 class MiniHub(Device):
     """Mini Hub device class."""
